@@ -2,12 +2,12 @@ package com.log28.groupie
 
 import com.log28.R
 import com.xwray.groupie.kotlinandroidextensions.Item
-import com.xwray.groupie.kotlinandroidextensions.ViewHolder
+import com.xwray.groupie.kotlinandroidextensions.GroupieViewHolder
 import kotlinx.android.synthetic.main.option_activity_header_item.*
 
 
 class OptionHeader(val string: String): Item() {
-    override fun bind(viewHolder: ViewHolder, position: Int) {
+    override fun bind(viewHolder: GroupieViewHolder, position: Int) {
         viewHolder.option_item_header_name.text = string
     }
 
