@@ -1,12 +1,12 @@
 package com.log28.groupie
 
 import com.xwray.groupie.kotlinandroidextensions.Item
-import com.xwray.groupie.kotlinandroidextensions.ViewHolder
+import com.xwray.groupie.kotlinandroidextensions.GroupieViewHolder
 import kotlinx.android.synthetic.main.cycle_overview_item.*
 import com.log28.R
 
 class OverviewItem(val string: String): Item() {
-    override fun bind(viewHolder: ViewHolder, position: Int) {
+    override fun bind(viewHolder: GroupieViewHolder, position: Int) {
         viewHolder.cycle_overview__item.text = string
     }
 
