@@ -4,12 +4,12 @@ import android.graphics.Color
 import android.os.AsyncTask
 import android.os.Bundle
 import android.preference.PreferenceManager
-import android.support.v4.app.Fragment
-import com.github.paolorotolo.appintro.AppIntro2
-import com.github.paolorotolo.appintro.AppIntro2Fragment
+import androidx.fragment.app.Fragment
+import com.github.appintro.AppIntro
+import com.github.appintro.AppIntroFragment
 import com.log28.R
 
-class AppIntroActivity: AppIntro2() {
+class AppIntroActivity: AppIntro() {
     var setupComplete = false
 
     override fun onCreate(savedInstanceState: Bundle?) {
@@ -17,9 +17,9 @@ class AppIntroActivity: AppIntro2() {
 
         // Note that we do not let users skip this because we need to
         // know cycle and period lengths for the app to function
-        showSkipButton(false)
+        isWizardMode = true
 
-        addSlide(AppIntro2Fragment.newInstance(this.resources.getString(R.string.welcome),
+        addSlide(AppIntroFragment.newInstance(this.resources.getString(R.string.welcome),
                 this.resources.getString(R.string.welcome_description),
                 R.drawable.ic_notebook, Color.parseColor("#1976D2")))
         addSlide(CycleIntroFragment.newInstance())
